"""tables creation

Revision ID: 379008363046
Revises: 
Create Date: 2020-12-18 13:14:28.183976

"""
import sqlalchemy as sa
from alembic import op
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = "379008363046"
down_revision = None
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "environment_build",
        sa.Column("build_uuid", sa.String(length=36), nullable=False),
        sa.Column("project_uuid", sa.String(length=36), nullable=False),
        sa.Column("environment_uuid", sa.String(length=36), nullable=False),
        sa.Column("project_path", sa.String(length=4096), nullable=False),
        sa.Column("requested_time", sa.DateTime(), nullable=False),
        sa.Column("started_time", sa.DateTime(), nullable=True),
        sa.Column("finished_time", sa.DateTime(), nullable=True),
        sa.Column("status", sa.String(length=15), nullable=True),
        sa.PrimaryKeyConstraint("build_uuid", name=op.f("pk_environment_build")),
        sa.UniqueConstraint("build_uuid", name=op.f("uq_environment_build_build_uuid")),
    )
    op.create_index(
        op.f("ix_environment_build_environment_uuid"),
        "environment_build",
        ["environment_uuid"],
        unique=False,
    )
    op.create_index(
        op.f("ix_environment_build_project_path"),
        "environment_build",
        ["project_path"],
        unique=False,
    )
    op.create_index(
        op.f("ix_environment_build_project_uuid"),
        "environment_build",
        ["project_uuid"],
        unique=False,
    )
    op.create_index(
        "uuid_proj_env_index",
        "environment_build",
        ["project_uuid", "environment_uuid"],
        unique=False,
    )
    op.create_table(
        "experiments",
        sa.Column("experiment_uuid", sa.String(length=36), nullable=False),
        sa.Column("project_uuid", sa.String(length=36), nullable=True),
        sa.Column("pipeline_uuid", sa.String(length=36), nullable=True),
        sa.Column("total_number_of_pipeline_runs", sa.Integer(), nullable=False),
        sa.Column("scheduled_start", sa.DateTime(), nullable=False),
        sa.Column(
            "completed_pipeline_runs",
            sa.Integer(),
            server_default=sa.text("0"),
            nullable=True,
        ),
        sa.PrimaryKeyConstraint("experiment_uuid", name=op.f("pk_experiments")),
    )
    op.create_table(
        "interactive_sessions",
        sa.Column("project_uuid", sa.String(length=36), nullable=False),
        sa.Column("pipeline_uuid", sa.String(length=36), nullable=False),
        sa.Column("status", sa.String(length=10), nullable=True),
        sa.Column("jupyter_server_ip", sa.String(length=15), nullable=True),
        sa.Column(
            "notebook_server_info",
            postgresql.JSONB(astext_type=sa.Text()),
            nullable=True,
        ),
        sa.Column(
            "container_ids", postgresql.JSONB(astext_type=sa.Text()), nullable=True
        ),
        sa.PrimaryKeyConstraint(
            "project_uuid", "pipeline_uuid", name=op.f("pk_interactive_sessions")
        ),
        sa.UniqueConstraint(
            "jupyter_server_ip", name=op.f("uq_interactive_sessions_jupyter_server_ip")
        ),
        sa.UniqueConstraint(
            "notebook_server_info",
            name=op.f("uq_interactive_sessions_notebook_server_info"),
        ),
    )
    op.create_table(
        "pipeline_runs",
        sa.Column("project_uuid", sa.String(length=36), nullable=True),
        sa.Column("pipeline_uuid", sa.String(length=36), nullable=False),
        sa.Column("run_uuid", sa.String(length=36), nullable=False),
        sa.Column("status", sa.String(length=15), nullable=True),
        sa.Column("started_time", sa.DateTime(), nullable=True),
        sa.Column("finished_time", sa.DateTime(), nullable=True),
        sa.Column("type", sa.String(length=50), nullable=True),
        sa.Column("experiment_uuid", sa.String(length=36), nullable=True),
        sa.Column("pipeline_run_id", sa.Integer(), nullable=True),
        sa.ForeignKeyConstraint(
            ["experiment_uuid"],
            ["experiments.experiment_uuid"],
            name=op.f("fk_pipeline_runs_experiment_uuid_experiments"),
            ondelete="CASCADE",
        ),
        sa.PrimaryKeyConstraint("run_uuid", name=op.f("pk_pipeline_runs")),
    )
    op.create_table(
        "pipeline_run_image_mappings",
        sa.Column("run_uuid", sa.String(length=36), nullable=False),
        sa.Column("orchest_environment_uuid", sa.String(length=36), nullable=False),
        sa.Column("docker_img_id", sa.String(), nullable=False),
        sa.ForeignKeyConstraint(
            ["run_uuid"],
            ["pipeline_runs.run_uuid"],
            name=op.f("fk_pipeline_run_image_mappings_run_uuid_pipeline_runs"),
            ondelete="CASCADE",
        ),
        sa.PrimaryKeyConstraint(
            "run_uuid",
            "orchest_environment_uuid",
            "docker_img_id",
            name=op.f("pk_pipeline_run_image_mappings"),
        ),
        sa.UniqueConstraint(
            "run_uuid",
            "docker_img_id",
            name=op.f("uq_pipeline_run_image_mappings_run_uuid_docker_img_id"),
        ),
        sa.UniqueConstraint(
            "run_uuid",
            "orchest_environment_uuid",
            name=op.f(
                "uq_pipeline_run_image_mappings_run_uuid_orchest_environment_uuid"
            ),
        ),
    )
    op.create_index(
        op.f("ix_pipeline_run_image_mappings_docker_img_id"),
        "pipeline_run_image_mappings",
        ["docker_img_id"],
        unique=False,
    )
    op.create_index(
        op.f("ix_pipeline_run_image_mappings_orchest_environment_uuid"),
        "pipeline_run_image_mappings",
        ["orchest_environment_uuid"],
        unique=False,
    )
    op.create_index(
        op.f("ix_pipeline_run_image_mappings_run_uuid"),
        "pipeline_run_image_mappings",
        ["run_uuid"],
        unique=False,
    )
    op.create_table(
        "pipeline_run_steps",
        sa.Column("run_uuid", sa.String(length=36), nullable=False),
        sa.Column("step_uuid", sa.String(length=36), nullable=False),
        sa.Column("status", sa.String(length=15), nullable=True),
        sa.Column("started_time", sa.DateTime(), nullable=True),
        sa.Column("finished_time", sa.DateTime(), nullable=True),
        sa.ForeignKeyConstraint(
            ["run_uuid"],
            ["pipeline_runs.run_uuid"],
            name=op.f("fk_pipeline_run_steps_run_uuid_pipeline_runs"),
            ondelete="CASCADE",
        ),
        sa.PrimaryKeyConstraint(
            "run_uuid", "step_uuid", name=op.f("pk_pipeline_run_steps")
        ),
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table("pipeline_run_steps")
    op.drop_index(
        op.f("ix_pipeline_run_image_mappings_run_uuid"),
        table_name="pipeline_run_image_mappings",
    )
    op.drop_index(
        op.f("ix_pipeline_run_image_mappings_orchest_environment_uuid"),
        table_name="pipeline_run_image_mappings",
    )
    op.drop_index(
        op.f("ix_pipeline_run_image_mappings_docker_img_id"),
        table_name="pipeline_run_image_mappings",
    )
    op.drop_table("pipeline_run_image_mappings")
    op.drop_table("pipeline_runs")
    op.drop_table("interactive_sessions")
    op.drop_table("experiments")
    op.drop_index("uuid_proj_env_index", table_name="environment_build")
    op.drop_index(
        op.f("ix_environment_build_project_uuid"), table_name="environment_build"
    )
    op.drop_index(
        op.f("ix_environment_build_project_path"), table_name="environment_build"
    )
    op.drop_index(
        op.f("ix_environment_build_environment_uuid"), table_name="environment_build"
    )
    op.drop_table("environment_build")
    # ### end Alembic commands ###
